.. pymeasurement documentation master file, created by
   sphinx-quickstart on Tue Feb  7 02:24:49 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pymeasurement's documentation!
=========================================
A Measurement Calculator with Fixed Point Precision, Uncertainties, and Units.

Get started with pymeasurement by reading the :doc:`get_started` section.

Read the :doc:`documentation/index` section for detailed information on the package.

View on `PyPi <https://pypi.org/project/pymeasurement/>`_ and on `Github <https://github.com/Saptak625/pymeasurement>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   get_started
   basics
   initialize
   operations
   aggregate_operations
   table_operations
   physics_example
   chemistry_example
   lab_example
   documentation/index
   genindex

